EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'VsixPackages_DeletePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a package from a feed.'
GO

IF OBJECT_ID('[VsixPackages_DeletePackage]') IS NOT NULL DROP PROCEDURE [VsixPackages_DeletePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [VsixPackages_DeletePackage]
(
	@Feed_Id INT,
	@Package_Id VARCHAR(100),
	@Major_Number INT,
	@Minor_Number INT,
	@Build_Number INT,
	@Revision_Number INT
)
AS
BEGIN

	SET NOCOUNT ON

	BEGIN TRY
		BEGIN TRANSACTION

		IF EXISTS(SELECT * FROM [VsixPackages] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [Package_Id] = @Package_Id AND [Major_Number] = @Major_Number AND [Minor_Number] = @Minor_Number AND [Build_Number] = @Build_Number AND [Revision_Number] = @Revision_Number)
		BEGIN

			DECLARE @Version_Text VARCHAR(200)
			SET @Version_Text = CAST(@Major_Number AS VARCHAR(50)) + '.' + CAST(@Minor_Number AS VARCHAR(50)) + '.' + CAST(@Build_Number AS VARCHAR(50)) + '.' + CAST(@Revision_Number AS VARCHAR(50))

			DELETE FROM [VsixPackages]
			 WHERE [Feed_Id] = @Feed_Id
			   AND [Package_Id] = @Package_Id
			   AND [Major_Number] = @Major_Number
			   AND [Minor_Number] = @Minor_Number
			   AND [Build_Number] = @Build_Number
			   AND [Revision_Number] = @Revision_Number

			EXEC [Events_RaiseEvent] 'PKGDEL', @Feed_Id, 'Package_Name', @Package_Id, 'Package_Version', @Version_Text

		END

		COMMIT
	END TRY BEGIN CATCH
		IF XACT_STATE()<>0 ROLLBACK
		EXEC [HandleError]
	END CATCH

END
GO

GRANT EXECUTE ON [VsixPackages_DeletePackage] TO [ProGetUser_Role]
GO
