EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Webhooks_CreateOrUpdateWebhook',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Webhook_Id',
    /* Description_Text        */ 'Creates or modifies a webhook.'
GO

IF OBJECT_ID('[Webhooks_CreateOrUpdateWebhook]') IS NOT NULL DROP PROCEDURE [Webhooks_CreateOrUpdateWebhook]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [Webhooks_CreateOrUpdateWebhook]
(
	@Feed_Id INT,
	@Webhook_Name NVARCHAR(50),
	@EventType_Name VARCHAR(20),
	@Target_Url VARCHAR(200),
	@Method_Name VARCHAR(10),
	@Condition_Text VARCHAR(MAX),
	@Headers_Bytes VARBINARY(MAX),
	@Content_Bytes VARBINARY(MAX),
	@Webhook_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

	IF @Webhook_Id IS NULL BEGIN

		INSERT INTO [Webhooks]
		(
			[Feed_Id],
			[Webhook_Name],
			[EventType_Name],
			[Target_Url],
			[Method_Name],
			[Condition_Text],
			[Headers_Bytes],
			[Content_Bytes]
		)
		VALUES
		(
			@Feed_Id,
			@Webhook_Name,
			@EventType_Name,
			@Target_Url,
			@Method_Name,
			@Condition_Text,
			@Headers_Bytes,
			@Content_Bytes
		)

		SET @Webhook_Id = SCOPE_IDENTITY()

	END ELSE BEGIN

		UPDATE [Webhooks]
		   SET [Feed_Id] = @Feed_Id,
		       [Webhook_Name] = @Webhook_Name,
		       [EventType_Name] = @EventType_Name,
			   [Target_Url] = @Target_Url,
			   [Method_Name] = @Method_Name,
			   [Condition_Text] = @Condition_Text,
			   [Headers_Bytes] = @Headers_Bytes,
			   [Content_Bytes] = @Content_Bytes
		 WHERE [Webhook_Id] = @Webhook_Id

	END

END
GO

GRANT EXECUTE ON [Webhooks_CreateOrUpdateWebhook] TO [ProGetUser_Role]
GO